contacts.RoleType (Function) — amici1

# `contacts.RoleType` (Function)

RoleType(id, name, can_sign, name_de, name_fr)

Master tables : contacts.RoleTypes (Functions)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : A translatable designation. Used e.g. in document templates for contracts.

- Authorized to sign (can_sign) : Whether this is a signer function.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.contacts.models.RoleType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.contacts.models.RoleType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.contacts.models.RoleType.overview`.

Referenced from cal.Room.contact_role, contacts.Role.type, courses.Line.contact_role, excerpts.Excerpt.contact_role

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
name | Designation | A translatable designation. Used e.g. in document templates for contracts.
can_sign | Authorized to sign | Whether this is a signer function.
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |